/* Define to your system's socket descriptor type. */
#undef SOCKET_TYPE

/* Define this to use the -lncurses or -lcurses support. */
#undef USE_CURSES

/* Define this to use the -lslang support. */
#undef USE_SLANG

/* Define this to `int' if your curses doesn't typedef attr_t */
#undef attr_t

/* Define this to use the new key handler. */
#undef USE_OWN_KEY_PARSING

/* Define this to compile the system under WINE. */
#undef WINE

/* Define this to the system config directory. */
#undef SYSCONFDIR

/* Define this if your system already has a def for UCHAR. */
#undef HAVE_UCHAR

/* define this when creating a binary distribution */
#undef BINARY_RELEASE
